__version__ = "0.1.1"
__author__ = "Job Snijders"
__author_email__ = "job@instituut.net"
__copyright__ = "Copyright 2016, Job Snijders"
__license__ = "BSD 2-Clause"
__status__ = "Development"
__url__ = "https://github.com/job/rtrsub"
